@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,6 +10,8 @@
 
 #include <QPixmap>
 
+#include <memory>
+
 namespace Gravatar
 {
 class GravatarCachePrivate;
@@ -37,7 +39,7 @@ public:
 
 private:
     Q_DISABLE_COPY(GravatarCache)
-    GravatarCachePrivate *const d;
+    std::unique_ptr<GravatarCachePrivate> const d;
 };
 }
 
