@@ -1,14 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef GRAVATARCONFIGWIDGET_H
-#define GRAVATARCONFIGWIDGET_H
+#pragma once
 
 #include "gravatar_export.h"
 #include <QWidget>
+
+#include <memory>
+
 namespace Gravatar
 {
 class GravatarConfigWidgetPrivate;
@@ -19,7 +21,7 @@ class GRAVATAR_EXPORT GravatarConfigWidget : public QWidget
     Q_OBJECT
 public:
     explicit GravatarConfigWidget(QWidget *parent = nullptr);
-    ~GravatarConfigWidget();
+    ~GravatarConfigWidget() override;
 
     void save();
     void doLoadFromGlobalSettings();
@@ -32,8 +34,8 @@ private:
     void slotGravatarEnableChanged(bool state);
     void slotConfigureSettings();
     void updateWidgetState(bool state);
-    GravatarConfigWidgetPrivate *const d;
+
+    std::unique_ptr<GravatarConfigWidgetPrivate> const d;
 };
 }
 
-#endif // GRAVATARCONFIGWIDGET_H
