@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ class GRAVATAR_EXPORT GravatarDownloadPixmapDialog : public QDialog
     Q_OBJECT
 public:
     explicit GravatarDownloadPixmapDialog(QWidget *parent = nullptr);
-    ~GravatarDownloadPixmapDialog();
+    ~GravatarDownloadPixmapDialog() override;
 
     Q_REQUIRED_RESULT QPixmap gravatarPixmap() const;
 
